#ifndef NT2_INCLUDE_FUNCTIONS_IF_ZERO_ELSE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IF_ZERO_ELSE_HPP_INCLUDED

#include <nt2/boolean/include/functions/if_zero_else.hpp>

#endif
